@@ -49,8 +49,8 @@ def _get_cookie_data(oauth2_cookie_config, cookie_data):
     return _cookie_data
 
 
-def _get_state_cookie(config, state):
-    _cookie_content = {'state': state, 'type': 'state'}
+def _get_state_cookie(config, state, req_uri):
+    _cookie_content = {'state': state, 'type': 'state', 'request_uri': req_uri}
     data = b64encode(json.dumps(_cookie_content).encode('utf-8'))
     data = _get_signer(config).sign(data)
     return data
@@ -60,7 +60,11 @@ async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
     cookie_data = {}
     _oauth_cookie_configs = _get_cookie_configs(config)
     for oauth2_cookie_name, oauth2_cookie_config in _oauth_cookie_configs.items():
-        if any(scope['path'].startswith(p) for p in oauth2_cookie_config['uris']):
+        _uri_index = [
+            oauth2_cookie_config['uris'].index(i) for i in oauth2_cookie_config['uris'] if scope['path'].startswith(i)
+        ]
+        if len(_uri_index) > 0:
+            oauth2_cookie_path = oauth2_cookie_config['uris'][_uri_index[0]]
             oauth2_cookie_config = oauth2_cookie_config['config']
             # TODO: get path
             http_connection = HTTPConnection(scope)
@@ -87,12 +91,12 @@ async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
                 _request = Request(scope, receive)
                 _client = OAuth2Session(
                     client_id=oauth2_cookie_config['client_id'],
-                    redirect_uri=str(_request.url)
+                    redirect_uri=oauth2_cookie_path
                 )
                 _auth_url, state = _client.authorization_url(f"{oauth2_cookie_config['idp']}/authorize")
                 response = RedirectResponse(_auth_url, status_code=307)
                 response.set_cookie(
-                    key=oauth2_cookie_name, value=_get_state_cookie(oauth2_cookie_config, state),
+                    key=oauth2_cookie_name, value=_get_state_cookie(oauth2_cookie_config, state, str(_request.url)),
                     secure=True, samesite='none', httponly=True, expires='session'
                 )
                 return response(scope, receive, send)
